#
# spec file for package remmina
#
# Copyright (c) 2019 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%bcond_with nx
Name:           remmina
Version:        1.3.4
Release:        lp150.2.3.1
Summary:        Versatile Remote Desktop Client
License:        GPL-2.0-or-later
Group:          Productivity/Networking/Other
Url:            http://www.remmina.org/
Source0:        https://gitlab.com/Remmina/Remmina/-/archive/v%{version}/Remmina-v%{version}.tar.bz2
BuildRequires:  cmake
BuildRequires:  ed
BuildRequires:  fdupes
BuildRequires:  intltool
BuildRequires:  libgcrypt-devel
BuildRequires:  libjpeg-devel
BuildRequires:  pkgconfig
BuildRequires:  update-desktop-files
BuildRequires:  pkgconfig(atk)
BuildRequires:  pkgconfig(avahi-glib)
BuildRequires:  pkgconfig(cairo)
BuildRequires:  pkgconfig(freerdp2)
BuildRequires:  pkgconfig(gdk-pixbuf-2.0)
BuildRequires:  pkgconfig(glib-2.0)
BuildRequires:  pkgconfig(gnutls)
BuildRequires:  pkgconfig(gtk+-3.0)
BuildRequires:  pkgconfig(json-glib-1.0)
BuildRequires:  pkgconfig(libsecret-1)
BuildRequires:  pkgconfig(libsoup-2.4)
BuildRequires:  pkgconfig(libssh)
BuildRequires:  pkgconfig(libvncserver)
BuildRequires:  pkgconfig(pango)
BuildRequires:  pkgconfig(spice-client-gtk-3.0)
BuildRequires:  pkgconfig(telepathy-glib)
BuildRequires:  pkgconfig(vte-2.91)
BuildRequires:  pkgconfig(winpr2)
BuildRequires:  pkgconfig(xkbfile)
Recommends:     %{name}-lang
Recommends:     %{name}-plugin-rdp
Recommends:     %{name}-plugin-secret
Recommends:     %{name}-plugin-vnc
Provides:       %{name}-plugins-common = %{version}
Obsoletes:      %{name}-plugins-common < 1.0.0
%if 0%{?suse_version} > 1500
BuildRequires:  pkgconfig(wayland-client)
%endif
%if 0%{?is_opensuse}
BuildRequires:  pkgconfig(appindicator3-0.1)
%endif

%description
Remmina is a remote desktop client written in GTK+, aiming to be useful for
system administrators and travellers, who need to work with lots of remote
computers in front of either large monitors or tiny netbooks. Remmina supports
multiple network protocols such as RDP, VNC, NX, XDMCP and SSH via separate
plugins in an integrated and consistant user interface.

%package kiosk
Summary:        Login manager extension for a Remmina kiosk mode
Group:          Productivity/Networking/Other
Requires:       remmina = %{version}

%description kiosk
This package installs a Remmina Kiosk mode to the list of the
available sessions for all freedesktop compliant login managers.

%package devel
Summary:        Development Files for %{name}
Group:          Development/Libraries/Other
Requires:       %{name} = %{version}-%{release}

%description devel
This package contains header files needed for developing plugins for
Remmina.

%package plugin-exec
Summary:        Plugin for Remmina to allow execution of local commands
Group:          Productivity/Networking/Other
Requires:       remmina = %{version}

%description plugin-exec
This package provides a plugin for Remmina allowing the execution of
local commands.

%package plugin-spice
Summary:        SPICE Protocol Plugin for Remmina
Group:          Productivity/Networking/Other
Requires:       remmina = %{version}

%description plugin-spice
This package provides the SPICE protocol plugin for Remmina.

%package plugin-xdmcp
Summary:        XDMCP Protocol Plugin for Remmina
Group:          Productivity/Networking/Other
Requires:       remmina = %{version}

%description plugin-xdmcp
This package provides the XDMCP protocol plugin for Remmina.

%if %{with nx}
%package plugin-nx
Summary:        NX Protocol Plugin for Remmina
Group:          Productivity/Networking/Other
Requires:       NX
Requires:       remmina = %{version}

%description plugin-nx
This package provides the NX protocol plugin for Remmina.
%endif

%package plugin-rdp
Summary:        RDP Protocol Plugin for Remmina
Group:          Productivity/Networking/Other
Requires:       freerdp
Requires:       remmina = %{version}

%description plugin-rdp
This package provides the RDP protocol plugin for Remmina.

%package plugin-st
Summary:        Simple terminal Plugin for Remmina
Group:          Productivity/Networking/Other
Requires:       remmina = %{version}

%description plugin-st
This package provides the simple terminal plugin for Remmina.


%package plugin-vnc
Summary:        VNC Protocol Plugin for Remmina
Group:          Productivity/Networking/Other
Requires:       remmina = %{version}

%description plugin-vnc
This package provides the RDP protocol plugin for Remmina.

%package plugin-telepathy
Summary:        Telepathy Protocol Plugin for Remmina
Group:          Productivity/Networking/Other
Requires:       remmina = %{version}

%description plugin-telepathy
This package provides the Telepathy plugin for Remmina.

%package plugin-secret
Summary:        Gnome Keyring Pasword Manager Plugin for Remmina
Group:          Productivity/Networking/Other
Requires:       remmina = %{version}
Provides:       remmina-plugins-gnome = %{version}
Obsoletes:      remmina-plugins-gnome < %{version}

%description plugin-secret
This package provides a Remmina plugin for the GNOME keyring password manager.

%lang_package

%prep
%setup -q -n Remmina-v%{version}

%build
export LDFLAGS="-pie"
export CFLAGS="%{optflags} -fPIE -pie"

%if 0%{?is_opensuse}
%cmake
%else
%cmake -DWITH_APPINDICATOR=OFF
%endif

make %{?_smp_mflags}

%install
%cmake_install

%if %{without nx}
rm -f %{buildroot}%{_libdir}/remmina/plugins/remmina-plugin-nx.so \
    %{buildroot}%{_datadir}/icons/hicolor/*/emblems/remmina-nx.png
%endif

%suse_update_desktop_file org.remmina.Remmina Network RemoteAccess GTK

%fdupes %{buildroot}%{_datadir}/remmina

%fdupes %{buildroot}%{_datadir}/icons/hicolor/*/actions

%find_lang %{name}

# Begin: all icons/desktop updates only for suse < 1500
%if 0%{?suse_version} < 1500
%post
%desktop_database_post
%icon_theme_cache_post

%postun
%desktop_database_postun
%icon_theme_cache_postun

%post plugin-exec
%icon_theme_cache_post

%postun plugin-exec
%icon_theme_cache_postun

%post plugin-spice
%icon_theme_cache_post

%postun plugin-spice
%icon_theme_cache_postun

%post plugin-xdmcp
%icon_theme_cache_post

%postun plugin-xdmcp
%icon_theme_cache_postun

%if %{with nx}
%post plugin-nx
%icon_theme_cache_post

%postun plugin-nx
%icon_theme_cache_postun
%endif

%post plugin-rdp
%icon_theme_cache_post

%postun plugin-rdp
%icon_theme_cache_postun

%postun plugin-st
%icon_theme_cache_postun

%post  plugin-vnc
%icon_theme_cache_post

%postun plugin-vnc
%icon_theme_cache_postun

%post plugin-telepathy
%icon_theme_cache_post

%postun plugin-telepathy
%icon_theme_cache_postun

# end: only for suse < 1500
%endif

%files
%license LICENSE LICENSE.OpenSSL
%doc AUTHORS CHANGELOG.md README.md
%{_bindir}/%{name}
%{_datadir}/applications/%{name}-file.desktop
%{_datadir}/applications/org.remmina.Remmina.desktop
%{_datadir}/icons/hicolor/*/actions/*
%{_datadir}/icons/hicolor/*/apps/*
%{_datadir}/icons/hicolor/scalable/emblems/remmina-sftp-symbolic.svg
%{_datadir}/icons/hicolor/scalable/emblems/remmina-ssh-symbolic.svg
%dir %{_datadir}/metainfo
%{_datadir}/metainfo/org.remmina.Remmina.appdata.xml
%{_datadir}/mime/packages/%{name}-mime.xml
%{_datadir}/%{name}
%dir %{_libdir}/%{name}
%dir %{_libdir}/%{name}/plugins/
%{_mandir}/man1/%{name}.1%{?ext_man}

%files kiosk
%{_datadir}/gnome-session
%dir %{_datadir}/gnome-session/sessions
%{_datadir}/gnome-session/sessions/remmina-gnome.session
%{_bindir}/gnome-session-remmina
%{_bindir}/remmina-gnome
%{_mandir}/man1/gnome-session-remmina.1%{?ext_man}
%{_mandir}/man1/remmina-gnome.1%{?ext_man}
%{_datadir}/xsessions/remmina-gnome.desktop
%{_datadir}/applications/%{name}-gnome.desktop

%if !%{with nx}
%exclude %{_datadir}/icons/hicolor/scalable/emblems/remmina-nx-symbolic.svg
%endif

%files lang -f %{name}.lang

%files devel
%{_includedir}/%{name}/
%{_libdir}/pkgconfig/%{name}.pc

%files plugin-exec
%{_libdir}/remmina/plugins/remmina-plugin-exec.so
%{_datadir}/icons/hicolor/scalable/emblems/remmina-tool-symbolic.svg

%files plugin-spice
%{_libdir}/remmina/plugins/remmina-plugin-spice.so
%{_datadir}/icons/hicolor/scalable/emblems/remmina-spice-ssh-symbolic.svg
%{_datadir}/icons/hicolor/scalable/emblems/remmina-spice-symbolic.svg

%files plugin-xdmcp
%{_libdir}/remmina/plugins/remmina-plugin-xdmcp.so
%{_datadir}/icons/hicolor/scalable/emblems/remmina-xdmcp-ssh-symbolic.svg
%{_datadir}/icons/hicolor/scalable/emblems/remmina-xdmcp-symbolic.svg

%if %{with nx}
%files plugin-nx
%{_libdir}/remmina/plugins/remmina-plugin-nx.so
%{_datadir}/icons/hicolor/scalable/emblems/remmina-nx-symbolic.svg
%endif

%files plugin-rdp
%{_libdir}/remmina/plugins/remmina-plugin-rdp.so
%{_datadir}/icons/hicolor/scalable/emblems/remmina-rdp-ssh-symbolic.svg
%{_datadir}/icons/hicolor/scalable/emblems/remmina-rdp-symbolic.svg

%files plugin-st
%{_libdir}/remmina/plugins/remmina-plugin-st.so

%files plugin-vnc
%{_libdir}/remmina/plugins/remmina-plugin-vnc.so
%{_datadir}/icons/hicolor/scalable/emblems/remmina-vnc-ssh-symbolic.svg
%{_datadir}/icons/hicolor/scalable/emblems/remmina-vnc-symbolic.svg

%files plugin-telepathy
%dir %{_datadir}/telepathy
%dir %{_datadir}/telepathy/clients
%{_libdir}/remmina/plugins/remmina-plugin-telepathy.so
%{_datadir}/dbus-1/services/org.freedesktop.Telepathy.Client.Remmina.service
%{_datadir}/telepathy/clients/Remmina.client

%files plugin-secret
%{_libdir}/remmina/plugins/remmina-plugin-secret.so

%changelog
* Wed Mar 13 2019 Felix Zhang <fezhang@suse.com>
- Update to new upstream release 1.3.4
  * Updated to use core18 and gnome-3-28-1804 !1797
  * Snap: Build snap in CI and publish to the edge channel for
    builds against master !1810
  * Resolve "SSH public key cannot be imported: Access denied for
    'none'. Authentication that can continie: publickey" !1811
  * snap: Ensure the icon is installed !1812
* Thu Feb 28 2019 Johannes Weberhofer <jweberhofer@weberhofer.at>
- Update to new upstream release 1.3.3
  * Fix “Utranslated” typo + XHTML 1.0 strictness + move div CSS rule in style block
  * Revert autoclosed <script> tags. It seems to be badly surported
  * Remmina connection window refactoring
  * Adding Serial and parallel ports sharing
  * RemminaMain window refactoring - Removing deprecated functions.
  * Fix #1836 implementing the correct message panel when authenticating
  * Make ssh tunnel pwd user manageable and public key import
  * Fix Yes/No inversion
  * Updated translations: de, zh_CN, it, fr, tr, da, it
* Fri Feb  1 2019 jweberhofer@weberhofer.at
- Upgraded to 1.3.2 (boo#1123452, boo#1103557)
  * Change rcw size allocation wait algorithm, see issue #1809
  * Fix a couple of VNCI crashes, see issue #1821
  * Fix spice authentication, issue #1820
  * Update translations script fixes
  * Add a missing end point in an SSH error message
  * Translation Updates: fr, it
  * Cosmetic fixes
* Tue Jan 29 2019 jweberhofer@weberhofer.at
- Removed upstream patch remmina-1.3.0-removed-edit-delete.patch
- Upgraded to 1.3.1
  * fixed several typograpic errors
  * fixed VNC clipboard bug
  * Translations updated: en, de, tr, ru, it, es
  * Translations for SSH error messages
  * Performance improvement
  * Improved CSS Styles
  * rcw fixes
  * fix scrolling in fullscreen mode
  * fixed several issues
* Tue Jan 22 2019 jweberhofer@weberhofer.at
- Added remmina-1.3.0-removed-edit-delete.patch from upstream to
  exclude edit-delete.svg causing a conflict with kaffeine.
* Fri Jan 18 2019 jweberhofer@weberhofer.at
- Upgraded to 1.3.0
  * Use window resolution
  * rcw_preopen complete
  * RDP: new global parameter rdp_map_keycode
  * Use decimal instead of hex on rdp keycode map
  * Updated translations
  * Adding language detection
  * Auth panel widget placement
  * CSS modifications to adapt to stock Gnome and Gtk themes
  * Updated CSS to have black background in fullscreen
  * Gtk deprecation and CSS restzling
  * Gtk icon cache update during install phase
  * Correctly set focus after rcw_preopen
  * Icons and gtk fixes for rcw_reopen
  * Deprecates dynamic_resolution_width and height cfg params
  * Disable glyph cache by default
  * Fix crash when showing password panel
  * Fix crash when showing password panel
  * allow closing tab after error message panel is shown
  * Remove deprecated floating toolbar toplevel window
  * Fixed missing icons
  * Make menu items paintable by the application
  * Open connection window before connecting
  * Prevent toolbar signals while reconfiguring toolbar
  * Update toolbar button handling
  * Added xrdp friendly options, the "Relax Order Checks" and
    "Glyph Cache" options  are required for connections to xrdp
    servers (boo#1125549, boo#1129319)
  * RDP fixes: remove redundant rfi->width/rfi->height and more
  * RDP: correctly destroy rfi->surface during a desktop resize
  * RDP: move gdi_resize() to a better place
  * RDP: remove unneeded OrderSupport struct init
  * VNC: Fix possible crash during connection
  * Search box clear icon
  * Updated CONTIBUTING.md and README.md
  * Updated sponsor list
  * Updated wiki URLs
  * Updating coyright for year 2019
* Tue Nov 20 2018 jweberhofer@weberhofer.at
- Upgraded to 1.2.32.1
  * Add desktop-gnome-platform and fix themes in SNAP
  * Implement smartcard name setting
  * man+help: elaborate on file types of -connect and -edit cmd line options
  * RDP: add FREERDP_ERROR_SERVER_DENIED_CONNECTION message
  * Removing X11Forwarding code as it is wrong and causing issues
  * Updated turkish translation
* Sun Oct  7 2018 jweberhofer@weberhofer.at
- new plugin remmina-plugin-st (simple terminal)
- Upgraded to 1.2.32
  * Avoid to save last_success property if stats are not enabled.
  * GW auth data was saved in the server auth data.
  * Do not register socket plugins when X11 is not available.
  * Screenshot enhancements.
  * RDP GW authentication.
  * Adding global preference for search bar visibility.
  * Allow wayland backend again when GTK >= 3.22.27.
  * Added turkish translation.
  * Add option to honour https_proxy and http_proxy environment variable.
  * Force program name to app id.
  * Printing builds flags with remmina --full-version command option.
  * Fix KB grabbing when switching workspace.
  * Dealing correcthly with some deprecations, getting rid of most
    of G_GNUC_BEGIN_IGNORE_DEPRECATIONS.
  * Improving file type hadling.
  * Adding error check on remmina_pref_save.
  * Many bug fixing as usual.
* Mon Aug 27 2018 jweberhofer@weberhofer.at
- Upgraded to 1.2.31.4
  * Enhancements
  - Improving file type hadling.
  * Fixed bugs
  - Fix KB grabbing when switching workspace.
  - Fix some possible crashes when reading a remminafile.
  - Fixes a crash deleting XDMCP profile.
  - Fixing libssh deprecations.
- Upgraded to 1.2.31.3
  * Enhancements
  - Implement send ctrl+alt+fn keys.
  * Fixed bugs
  - Do not send stats if the remmina.pref file is read.
  - cmake: include libssh_threads only when available.
  - Set program class to REMMINA_APP_ID
* Wed Aug  8 2018 jengelh@inai.de
- Use noun phrasing in summary.
* Wed Aug  8 2018 jweberhofer@weberhofer.at
- New package remmina-kiosk is now available
- Upgraded to 1.2.31.2
  * Fixed bugs
  - Cannot minimize in fullscreen mode.
  - Crash with the RDP plugin.
  - Missing manual pages
- Upgraded to 1.2.31
  * Notables changes
  - Custom color schemes per profile for the SSH plugin
  - Flatpak updates and fixes
  - Kiosk mode with integration in the login manager
  - New Icons
  - SFTP tool password fixes
  - Several fixes around RDP and compilations issues (bsc#1117402)
* Tue May 29 2018 jweberhofer@weberhofer.at
- Upgraded to 1.2.30.1
  * Enhancements:
  - Move search bar below the header bar #1648
  - Failure to link with lld on OpenBSD #1604
  - Add search toggle #1653 (antenore)
  - Move search bar below the header. #1649 (antenore)
  * Fixed bugs:
  - RDP - Remmina process dies after entering password and clicking "OK" #1643
  - Fixing segmentation fault due to setting name NULL #1650 (antenore)
* Mon May 21 2018 jweberhofer@weberhofer.at
- Upgraded to 1.2.30
  * Enhancements:
  - HiDPI - Elements spacing in the headerbar is too low #1628
  - Failure to link with lld on OpenBSD #1604
  - RDP - Implement xfreerdp like --no-fastpath option #1596
  - 'remmina -c' accepting only configs with .remmina extension. #1454
  - [Feature Request] Add SPICE Native WebDAV shared folder support #1273
  - Register and support opening rdp files directly #1105
  - Panel Icon almost invisible #1006
  - Rename UNIQUE_APPNAME to REMMINA_APP_ID and use it wherever possible #1637 (larchunix)
  - Update new logo from Ura Design #1636 (antenore)
  - Increase headerbar elements spacing #1629 (antenore)
  - Support for "gatewayaccesstoken" (aka PAA) and "authentication level" RDP file properties #1621 (p-pautov)
  - Autodetect missing H264 on libfreerdp #1617 (giox069)
  - Project folder refactoring following the GNOME guidelines. 2nd batch. #1600 (antenore)
  - RDP: option to disable fast-path, fixes #1596 #1597 (giox069)
  - Term enhance - Color scheme import #1585 (antenore)
  * Fixed bugs:
  - Assert in remmina_pref_save #1570
  - Minor graphical issue on Ubuntu 18.04 with communitheme #1546
  - Security Bug: Unchecked call to gcry_control #830
  - "Floating point exception" while connecting to Windows 10 machine #681
  * Closed issues:
  - undefined symbol: vte_terminal_copy_clipboard_format #1591
  - RDP: Dynamic resolution updates don't work anymore after updating freerdp from 2.0.0_rc1 -> 2.0.0_rc2 #1576
  - Statrtup issues remmina / gnome / wayland / opensuse leap 15 beta #1558
  - VNCI connection not working! #1502
  - Highlight to copy - SSH #1434
  - Password not saving - encrypting *.remmina connection files #1423
  - Remmina crashes when sharing local printers and connecting through gateway #1405
  - Remmina lock screen when i use it to connect to Win10. #1396
  - Windows 10 BSOD on file copy #1019
  - ALT + F4 closes Remina remote Window #125
  * Merged pull requests:
  - Update italian translation #1631 (giox069)
  - Updated French po file #1630 (DevDef)
  - Write newline instead of return #1626 (weberhofer)
  - Updated German Translation #1624 (weberhofer)
  - Fix libssh deprecations in NX plugin #1613 (larchunix)
  - Headerbar spacing fixes #1607 (antenore)
  - Place headerbar in the main container. Fixes #1546 #1606 (antenore)
  - File list and indicator icon optimizations #1603 (giox069)
  - Project folder refactoring following the GNOME guidelines.
  - SPICE: add support for ssh tunnelling #1595 (larchunix)
  - Clang LLVM coverage flags #1594 (antenore)
  - GTK deprecation fixes #1592 (larchunix)
  - Undo commit 5b4e7f1 and change VNCI plugin description #1586 (giox069)
  - Fix a bunch of warnings #1583 (larchunix)
  - build: make appindicator include consistent with pkg-config flags #1582 (larchunix)
  - Add openSUSE info and instructions to README #1581 (jubalh)
  - Libssh has removed red.libssh.org #1574 (antenore)
  - periodic_usage_stats_uuid_prefix default value #1572 (antenore)
  - Use string constant #1569 (amtlib-dot-dll)
  - CMake cleanup #1568 (larchunix)
* Mon Apr  9 2018 jweberhofer@weberhofer.at
- Upgraded to 1.2.0-rcgit.28
  * Update Czech translation #1555 (AsciiWolf)
  * Switch back to x11 GTK backend under Wayland #1554 (giox069)
  * TCP_USER_TIMEOUT is in milliseconds #1553 (antenore)
  * Disable VNCI plugin #1550 (giox069)
  * Fix typo #1549 (mfvescovi)
  * Missing secret plugin handling #1548 (giox069)
  * Fixes for rcgit-28 #1547 (antenore)
* Wed Apr  4 2018 jweberhofer@weberhofer.at
- Desktop and icon updates will only be executed on suse
  versions prior to 1500.
* Wed Apr  4 2018 jweberhofer@weberhofer.at
- Activated telepathy plugin
- Enabled PIE
- Removed 644cd140a387c7b5d3805b8af9554e241d5d2954.patch: included
  in upstream
- Upgraded to 1.2.0-rcgit.28
  Implemented enhancements:
  * window has no focus when open ssh sessions #1530
  * Enhancement - Variables for pre- and post-commands #1485
  * Register and support opening rdp files -
    Mime improvements #1497 (antenore)
  * Profile and group name niddles in the pre/post
    commands #1492 (antenore)
  * Add xdmcp protocol to Keywords #1491 (mfvescovi)
  Fixed bugs:
  * Remmina fails to connect to SSH server without
    compression since 1.2.0-rcgit-27 (git rcgit-27) #1505
  * Pasting something that was copied in another VM that
    has since been closed causes crash #1484
  * SSH password authentication failed Wrong state
    during pending SSH call #1428
  * Fix clipboard cleanup, fixes issue #1484 #1486 (giox069)
  * telepathy: add dbus-glib-1 to link flags
  * Minor improvements on secure plugin and SNAP welcome message #1545
  * Fixes segmentation fault reported by #1499 #1503
  Other improvements:
  * Redesign - Removed icons where not needed #1535
  * Delay and use gtk_window_present_with_time() #1533
  * Update French translation #1524
  * Fixes for fedora bugs - desktop file and AppStream metadata #1523
  * Desktop data fixes #1522
  * Updated Hungarian translation #1517
  * Removed compression option as not compatible with all SSH servers #1506
* Fri Feb 16 2018 jweberhofer@weberhofer.at
- Add 644cd140a387c7b5d3805b8af9554e241d5d2954.patch: Fix
  compilation on factory (gh#FreeRDP/Remmina#1476)
* Thu Feb 15 2018 jweberhofer@weberhofer.at
- Updated dependencies
- Upgraded to 1.2.0-rcgit.27
  Implemented enhancements:
  * Remmina usage statistics collection
  * Remmina stats: Profiles and protocols counter
  * Updated freerdp on flatpak definition file
  Fixed bugs:
  * RDP + DYNRES: Screen is black immediately after connection and becames
    visible only later when DISP_DVC_CHANNEL_NAME is connected
  Other improvements:
  * Add initial [MS-RDPEGFX] software support
  * Permit SCALE_MODE_DYNRES before DISP_DVC_CHANNEL_NAME is enabled.
* Fri Jan  5 2018 jweberhofer@weberhofer.at
- Rename the plugin 'remmina-plugins-gnome' in 'remmina-plugin-secret'
- Added remmina-plugin-exec which allows execution of local commands
- Upgraded to 1.2.0-rcgit.26
  Implemented enhancements:
  * Allow external commands without protocols in create connection dialog
  * Option to completely hide the floating toolbar when in fullscreen.
  * Option to run Pre Command before ANYTHING else
  * Rename the plugin 'remmina-plugins-gnome' in 'remmina-plugins-secret'
  * Variables for pre- and post-commands
  * Implement an exec protocol plugin
  * Add SPICE Native WebDAV shared folder support
  * Added encryption algorithms options for SSH
  * SSH tunnel and pre/post commands improvements
  * Prior commands improvements
  * Add avahi host discovery for ssh and sftp plugins
  Fixed bugs:
  * Un-check of "Fullscreen on the same monitor as the connection window" won't save
  * Remmina resets screen resolution settings in RDP shortcut
  * SSH Tunneling is broken with SSH Agent with public key
  * Align SFTP and SSH plugins authentication and tunnel functionalities.
  * ssh_userauth_publickey_auto: should accept empty passphrase
  * Un-check of 'Fullscreen on the same monitor'
  Other improvements:
  * Updated translations
  * Fixed typos
  * Remove a couple of legacy "resolution" fields
* Thu Oct 26 2017 jweberhofer@weberhofer.at
- Upgraded to 1.2.0-rcgit.24
  Implemented enhancements:
  * Save SSH session to file
  * snap: Use the new desktop, desktop-legacy and wayland interfaces
  * snap: add password-manager-service interface for gnome-keyring
  * vte no longer optional
  * Fix window state saving for remmina_connection_window and main window
  * Crashes when I try opening Preference
  * Resolution and Passwords Not Saving in Connection Profiles
  * Focus-out-event should call UNFOCUS plugin feature, fixes
  * Fix some memory leaks
- Bugfixes
* Thu Oct 12 2017 jweberhofer@weberhofer.at
- Upgraded to 1.2.0-rcgit.21
  Implemented enhancements:
  * Feature Request: Create custom Terminal Color Schemes for SSH #1235
  * Enter key doesn't "Connect" when in Edit menu and password field is in focus #1233
  * Feature request - Option - Floating Desktop Name [$5] #815
  * Don't close connection windows when main window is closed #785
  * File association for connections #485
  * Implementation of dynamic resolution update for RDP #1292 (giox069)
  * Shortcutkey viewonly #1289 (antenore)
  * Simplify pthreads library detection #1274 (jabl)
  * Custom Color schemes for SSH #1272 (antenore)
  * RDP client keyboard mapping with GTK3 #1265 (giox069)
  * Make building the VNC plugin optional #1263 (diogocp)
  Fixed bugs:
  * copy / paste and charset #1300
  * Changes user name ssh tunnel (vnc over ssh) do not save. #1255
  * SSH username ignored for Tunnels for RDP #1254
  * Can't Specify X :display for XDMCP. #1251
  * "Remember last view mode for each connection" not respected in v1.2.0-rcgit.19 #1247
  * Remmina always remember password #1224
  * Host key not working with SPICE plugin connected to KVM client. #1035
  * Shortcutkey viewonly #1289 (antenore)
  Merged pull requests:
  * Fix charset conversion in VNC clipboard #1303 (giox069)
  * Add support for application/x-remmina MIME type, fixes #485 #1299 (giox069)
  * Reverted the notfication for the floating toolbar #1297 (antenore)
  * Fixes for notifications #1294 (giox069)
  * Server name is notified to the user everytime we enter a tab #1290 (antenore)
  * Exit strategy for Gnome Shell 3.26 #1287 (giox069)
  * Fix gtk redrawing in RDP plugin #1286 (giox069)
  * Gtk deprecations #1285 (giox069)
  * Add Keywords entry #1277 (mfvescovi)
  * Runtime paths for AppImage #1271 (giox069)
  * Get ssh_username from remmina profile - fixes #1255 #1267 (antenore)
  * Better button labelling and new save button #1250 (antenore)
* Fri Sep  1 2017 jweberhofer@weberhofer.at
- Enhancements to upgrade to the new freerdp package
- Removed build dependency: pkgconfig(webkit2gtk-4.0)
- Added new build dependency: libappindicator3-devel
- Built-dependency freerdp2-devel and dependency to libfreerdp2 has been
  introduced to force switching to the new freerdp2 package
- Suggest installation of RDP and VNC plugins
- Don't include app-indicator on SLES
- Cleaned up spec
- Upgraded to 1.2.0-rcgit.20
  Implemented enhancements:
  * Enter key doesn't "Connect" when in Edit menu and password field is in focus #1233
  * Set Linux as the default terminal color scheme. Fixes #1238 #1243 (antenore)
  Fixed bugs:
  * Remmina crashes each time I use FTP transfer #1257
  * Problems with some color schemes #1225
  Closed issues:
  * Color on SSH terminal window being applied #1238
  * Tray applet closing when last window gets closed #1236
  * Systray icon closes when closing 'Main Window' or RDP connection #1229
  * SSH Tunneling is broken with SSH Agent with public key #1228
  * Missing icons after compiling latest Git release #1221
  * RDP quality settings not saved #1216
  * Cannot connect after upgrading Ubuntu to 16.04 #946
  Merged pull requests:
  * passphrase not yet used in sftp connection - closes #1257 #1259 (antenore)
  * Added ssh_agent in the list of authorized method, fixes #1228 #1246 (antenore)
  * Connect when pressing enter in the password field #1242 (antenore)
  * Fixed terminal color palettes #1240 (antenore)
  * French translation update and other po files update with new strings to be translated #1239 (DevDef)
  * SSH Kerberos GSSAPI Auth #1237 (giox069)
  * Enter key doesn't "Connect" when in Edit menu and password field is in focus - #1233 #1234 (erichoog)
  * Fix link for issue #367 #1232 (erichoog)
  * Change Status Icon availability for gnome 3.16 #1230 (giox069)
- Upgraded to 1.2.0-rcgit.19
  Implemented enhancements:
  * SSH tunneling does not work with RDP server redirection #1175
  * Enhancement - Another User connected to the server, forcing [...] pop-up #1141
  * RD Gateway Doesn't Support different username/password #933
  * the checkbox, 'Save SSH Password', greyed out. #708
  * RD Gateway authentication doesn't work #511
  * Allow the user to hide the toolbar inside a remmina connection window #413
  * Support for RDP Gateway #347
  * Ssh improvements #1196 (antenore)
  * Implementing separate user and password for RD Gateway #1193 (antenore)
  * RDP: remove server hostname DNS check #1190 (giox069)
  * Pressing Enter in the Domain entry of Auth dialog submits #1163 (iivorait)
  * Add server name to popup warning #1142 (antenore)
  * Add an option to completely disable the floating toolbar in fullscreen mode #1135 (transistor1)
  * The host key should not affect subsequent key operations #1132 (nanxiongchao)
  Fixed bugs:
  * Remmina profile editor scrolling is broken #1179
  * Graphical issues when using byobu/tmux #1151
  * I always got an error message "SSH public key has changed!" #1129
  * problem with tui interfaces in remmina #1076
  * test bounty source #1048
  * Importing rdp file not successful #1039
  * Implementing separate user and password for RD Gateway #1193 (antenore)
  Closed issues:
  * RDP to Win10 makes ToolBar clear #1209
  * Upgrading to 1.2 failed #1202
  * Multiple NICs #1188
  * "Public Key (Automatic)" option does not work with ed25519 keys #1187
  * Cannot connect to Windows 10 after Creators Update (1703) #1186
  * Crashing on Load: Segfault #1185
  * Files in mounted sharefolders become terrabytes big. #1174
  * compilation on Debian 9 #1165
  * Clipboard sync is not working #1164
  * File Transfers to Share Folder Crashing Remmina 1.2.0-rcgit-18 Each Try #1159
  * Segfault when using the host SMB sharefolder on Windows (from Linux client) #1157
  * Custom RDP settings? #1146
  * Missing icons in remote session toolbar #1136
  * Opacity for pop up tool bar is too see-through #1131
  * option to remove fullscreen toolbar completely #1128
  * SSH terminal doesn't work #1125
  * Start remmina with fixed language #1119
  * Remmina Next is Corrupting the Unity Desktop #1111
  * Remove systemd dependency #1100
  * Keyboard Events #1096
  * No move or resize terminal window #1087
  * Connection Timeout - vfprintf.c no such file or directory - Segfault #1080
  * SSH password can't save , terminal auto disconnection #1078
  * Remmina getting down when used ssh & mc #1075
  * Only stored passwords when connecting via RD-Gateway #922
  * VNC over SSH tunnel very slow #713
  * Domain/Username/Password database #711
  * Remmina RDP hangs after second certificate confirmation when using RD gateway #706
  * SSH agent forwarding, tunnels and other nice stuff #692
  * When I open a RDP connexion on Microsoft Windows PC, SSH Client display is messing #663
  * Remmina doesn't respect ssh config files... #235
  * SSH: missed check availability of PubkicKey Auth on remote host before asking passphrase #176
  Merged pull requests:
  * Fixes for the exit strategy #1219 (giox069)
  * Issues 785 966 #1214 (giox069)
  * Ssh protocol plugin implementation #1206 (antenore)
  * The multi password changer #1203 (giox069)
  * Fix snap issues #1200 (dfiloni)
  * Terminal functionalities to make Remmina behave correctly with ncurses #1198 (antenore)
  * Fix multiple typos of 'transfered' word #1173 (mfvescovi)
  * RDP plugin: add password expired message and update po files #1170 (giox069)
  * Remmina --full-version command line option #1169 (antenore)
  * snapcraft: use snap-preload to get dynamic access to /snap path #1161 (3v1n0)
  * Inproved CodeTriage and Bountysource buttons #1143 (weberhofer)
  * Cmake clean #1140 (antenore)
  * Give precedence to libfreerdp2 and winpr2 libs #1138 (antenore)
  * travis: build the snap for PRs in Debug mode #1130 (3v1n0)
  * snap: optionally push all the built snaps on PRs to transfer.sh #1126 (3v1n0)
  * Small English nit (fullscreen_on_auto) #1124 (lnicola)
  * Fix german translation #1120 (giox069)
* Sun Aug 20 2017 zaitor@opensuse.org
- Drop obsolete and unused pkgconfig(unique-1.0) BuildRequires.
* Fri May 12 2017 tchvatal@suse.com
- Version update to version 1.2.0.rcgit.18:
  * Various fixes around, see the upstream Changelog
* Sun Feb  5 2017 mailaender@opensuse.org
- move README.SUSE to https://en.opensuse.org/Remmina
- update to version 1.2.0.rcgit.17
* Mon Jun 13 2016 mailaender@opensuse.org
- update to version 1.2.0.rcgit.13 as freerdp 1.0 isn't available anymore
- dropped patches:
  * remmina-close-ssh-tunnel-on-disconnect.patch
  * remmina-fix-desktop-file.patch
  * remmina-fix-fullscreen-with-multiple-monitors.patch
  * remmina-fix-install-paths.patch
  * remmina-fix-linker-issue.patch
  * remmina-fix-scrolling-in-vnc-plugin.patch
  * remmina-fix-window-resize.patch
  * remmina-gtk-2-22-support.patch
  * remmina-remove-inline-libvncserver.patch
  * remmina-vte-2.91-support.patch
* Tue Oct 13 2015 dimstar@opensuse.org
- openSUSE_Leap 42.1: also apply the patch for vte-2.91.
* Fri Sep  4 2015 dimstar@opensuse.org
- openSUSE Leap 42.1 (suse_version 1315) also has vte-2.91.
* Thu Jan 22 2015 gber@opensuse.org
- amend remmina-fix-install-paths.patch to fix the installation of
  headers (gh#FreeRDP/Remmina#292)
* Tue Oct  7 2014 gber@opensuse.org
- add remmina-vte-2.91-support.patch in order to support building
  against vte-2.91 for openSUSE >= 13.2
- rename README.SuSE to README.SUSE
* Tue Oct  7 2014 dmueller@suse.com
- fix build against Factory
* Sat Mar 23 2013 gber@opensuse.org
- enable TLS-support in VNC plugin (bnc#804320)
- add remmina-fix-scrolling-in-vnc-plugin.patch which fixes
  scrolling in the VNC plugin (backport from upstream git)
- add remmina-close-ssh-tunnel-on-disconnect.patch in order to
  close SSH tunnels on disconnect and avoid freezing (backport from
  upstream git)
- remmina-fix-window-resize.patch which fixes resizing the window
  (backport from upstream git)
- add remmina-fix-fullscreen-with-multiple-monitors.patch which
  fixes fullscreen mode with multiple monitors (backport from
  upstream git)
* Thu Aug 23 2012 gber@opensuse.org
- add missing dependency on gnutls
* Sat Aug 18 2012 gber@opensuse.org
- added remmina-remove-inline-libvncserver.patch in order to remove
  the inline copy of libvncserver (backport from upstream git)
* Mon Apr  2 2012 gber@opensuse.org
- use original tarball name to fix download check
* Mon Apr  2 2012 gber@opensuse.org
- disable the NX plugin by default
* Wed Mar 28 2012 gber@opensuse.org
- added separare patch remmina-fix-install-paths.patch in order to
  fix the installation paths
- specfile cleanup
- removed remmina-plugins-common, now provided by the main package
- split off -lang subpackage
* Wed Mar 21 2012 gankov@opensuse.org
- rewrote spec for using cmake
- merged with remmina-plugins into one source package (upstream
  now diestributes a single tarball with plugins)
- update to version 1.0.0
  + Main program design and functionality:
  * Switch to the CMake build system
  * Refactoring of code style
  * Changing file name convention
  + RDP protocol related:
  * Support for FreeRDP 1.0
  * Support for RemoteFX
  * Support for Network Level Authentication
  * Added certificate validation prompt
- added remmina-fix-linker-issue.patch which fixes a linking issue
  (backport from upstream git)
- added remmina-fix-desktop-file.patch which fixes the installation
  of the .desktop file (backport from upstream git)
- added remmina-gtk-2-22-support.patch in order to build on
  openSUSE 11.4 with GTK 2.22 as upstream requires 2.24+
* Thu Sep 29 2011 gber@opensuse.org
- libunique1 is available on Factory so use it
- do not recommend non-existent remmina-plugins
- add a note about plugins
* Thu Sep 29 2011 gber@opensuse.org
- change the pkgconfig(libssh) dependency to libssh-devel in the
  - devel subpackage
* Thu Sep 22 2011 gber@opensuse.org
- cleanup
  + added license/copyright header
  + improved description/summary
  + use SPDX license abbreviation
  + removed %%clean section
  + use the correct macros to update the icon/desktop file cache in
    %%post/%%postun
  + use pkgconfig symbols unconditionally (this can be handled
    at the project level)
  + removed empty NEWS
* Fri Apr  8 2011 lijewski.stefan@gmail.com
- spec cleanup, prepare to move X11:RemoteDesktop
* Mon Feb  7 2011 gav@qsolution.ru
- Update to version 0.9.3
  + Integrate scrolled window and fullscreen view modes into one button
  + Remove quick connect menu and consolidate the feature with Connection->New
  menu.
* Fri Nov  5 2010 michal.smrz@opensuse.cz
- Update to version 0.8.3
- Edited BuildRequires and Requires to match web pages
* Mon Sep 27 2010 michal.smrz@opensuse.cz
- merge with nilda package created by djs_core <admin@djscore.org>
* Mon Sep 27 2010 prusnak@opensuse.org
- spec cleanup
* Tue Sep 21 2010 lijewski.stefan@gmail.com
- initial package for openSUSE
